@@ -101,6 +101,7 @@ HEPBURN = {
 # Improvements are welcome.
 'ゕ': 'ka',
 'ㇰ': 'k',
+'ゖ': 'ke',
 'ヶ': 'ga',
 'こ': 'ko',
 'ㇱ': 'shi',
@@ -121,6 +122,16 @@ HEPBURN = {
 'ゎ': 'wa',
 'ㇷ゚': 'p',
 
+
+# small kana extension
+'𛅐': 'wi',
+'𛅑': 'we',
+'𛅒': 'wo',
+'𛅤': 'wi',
+'𛅥': 'we',
+'𛅦': 'wo',
+'𛅧': 'n',
+
 # digraphs
 'しゃ': 'sha',
 'しゅ': 'shu',
@@ -151,6 +162,10 @@ HEPBURN = {
 '】': ']',
 '・': '/',
 '，': ',',
+
+# other
+'゚': '', # combining handakuten by itself, just discard
+'゙': '', # combining dakuten by itself
 }
 
 KUNREISHIKI = dict(HEPBURN)
