@@ -82,7 +82,15 @@ SENTENCES = [
         # deal with combining dakuten
         ("青い春よさらば！", "Aoi haru yo saraba!"),
         # small ケ
-        ("齋藤タヶオ", "Saitou ta ke o")
+        ("齋藤タヶオ", "Saitou ta ke o"),
+        # っー
+        ("ずっーと", "Zu--to"),
+        # don't add spaces around apostrophe if it wasn't there
+        ("McDonald's", "McDonald's"),
+        # Following are quote weirdness. Not good but hard to fix.
+        # An issue is that ," or .' is a single token.
+        ("It's 'delicious.'", "It's ' delicious .'"),
+        ('"Hello," he said.', '" Hello ," he said.'),
         ]
 
 SENTENCES_KUNREI = [
@@ -105,6 +113,17 @@ NON_FOREIGN = [
         ("カツカレーは美味しい", "Katsu karee wa oishii"),
         ]
 
+TITLE = [
+        ('吾輩は猫である', 'Wagahai wa Neko de Aru'),
+        ('お話があります', 'Ohanashi ga Arimasu'),
+        ('図書館戦争', 'Toshokan Sensou'),
+        ('頑張って', 'Ganbatte'),
+        ('さらば愛しき人よ', 'Saraba Itoshiki Hito yo'),
+        ('愛せよ乙女', 'Aiseyo Otome'),
+        ('巴里は燃えているか', 'Paris wa Moete Iru ka'),
+        ]
+
+
 import pathlib
 here = pathlib.Path(__file__).parent.absolute()
 import json
@@ -144,6 +163,11 @@ def test_romaji_non_foreign(ja, roma):
     cut.use_foreign_spelling = False
     assert cut.romaji(ja) == roma
 
+@pytest.mark.parametrize('ja, roma', TITLE)
+def test_romaji_title(ja, roma):
+    cut = Cutlet()
+    assert cut.romaji(ja, title=True) == roma
+
 @pytest.mark.parametrize('ja, roma', [
     (None, ''),
     ('', '')
